@@ -9,13 +9,12 @@ from .rrset import RRset
 class Zone:
     def __init__(
         self, origin: str, rdclass: int = IN, relativize: bool = False
-    ) -> None:
-        ...
+    ) -> None: ...
 
-    def find_rrset(self, name: Union[Name, str], rdtype: int) -> RRset:
-        ...
+    def find_rrset(self, name: Union[Name, str], rdtype: int) -> RRset: ...
 
-    def replace_rdataset(self, name: Union[Name, str], replacement: Rdataset) -> None:
-        ...
+    def replace_rdataset(
+        self, name: Union[Name, str], replacement: Rdataset
+    ) -> None: ...
 
     ...
