@@ -1,20 +1,21 @@
 import asyncio
 import contextlib
+from typing import AsyncGenerator, cast
 
 
 class EchoServerProtocol(asyncio.DatagramProtocol):
-    def connection_made(self, transport):
-        self.transport = transport
+    def connection_made(self, transport: asyncio.BaseTransport) -> None:
+        self.transport = cast(asyncio.DatagramTransport, transport)
 
-    def datagram_received(self, data, addr):
+    def datagram_received(self, data: bytes, addr: tuple[str, int]) -> None:
         self.transport.sendto(data, addr)
 
 
 class EchoServer:
-    async def close(self):
+    async def close(self) -> None:
         self.udp_server.transport.close()
 
-    async def listen(self, host="127.0.0.1", port=0):
+    async def listen(self, host: str = "127.0.0.1", port: int = 0) -> None:
         loop = asyncio.get_event_loop()
 
         # listen for UDP
@@ -25,8 +26,8 @@ class EchoServer:
 
 
 @contextlib.asynccontextmanager
-async def run_echo_server(**kwargs):
-    server = EchoServer(**kwargs)
+async def run_echo_server() -> AsyncGenerator[EchoServer, None]:
+    server = EchoServer()
     await server.listen()
     try:
         yield server
